pub struct HighestLowestDelta { /* private fields */ }Expand description
Calculates absolute difference between highest and lowest values over the last length values for timeseries of type ValueType
Parameters
Has a single parameter length: PeriodType
length should be > 0
Input type
Input type is ValueType
Output type
Output type is ValueType
Output value is always >= 0.0
Examples
use yata::prelude::*;
use yata::methods::HighestLowestDelta;
let values = [1.0, 2.0, 3.0, 2.0, 1.0, 0.5, 2.0, 3.0];
let r = [0.0, 1.0, 2.0, 1.0, 2.0, 1.5, 1.5, 2.5];
let mut hld = HighestLowestDelta::new(3, &values[0]).unwrap();
(0..values.len()).for_each(|i| {
let v = hld.next(&values[i]);
assert_eq!(v, r[i]);
});Performance
O(length)
This method is relatively very slow compare to the other methods.
See also